summaryrefslogtreecommitdiff
path: root/src/vm/eetwain.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/vm/eetwain.cpp')
-rw-r--r--src/vm/eetwain.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/vm/eetwain.cpp b/src/vm/eetwain.cpp
index 4a02be7b82..99e9107189 100644
--- a/src/vm/eetwain.cpp
+++ b/src/vm/eetwain.cpp
@@ -3019,12 +3019,12 @@ unsigned SKIP_ALLOC_FRAME(int size, PTR_CBYTE base, unsigned offset)
return (SKIP_PUSH_REG(base, offset));
}
- if (size >= OS_PAGE_SIZE)
+ if (size >= (int)GetOsPageSize())
{
- if (size < (3 * OS_PAGE_SIZE))
+ if (size < int(3 * GetOsPageSize()))
{
- // add 7 bytes for one or two TEST EAX, [ESP+OS_PAGE_SIZE]
- offset += (size / OS_PAGE_SIZE) * 7;
+ // add 7 bytes for one or two TEST EAX, [ESP+GetOsPageSize()]
+ offset += (size / GetOsPageSize()) * 7;
}
else
{